@@ -10,6 +10,24 @@
 #include <Rmath.h>
 #include <stdbool.h>
 #include <R_ext/Rdynload.h>
+#include <rxode2parse.h>
+
+#define rc_buf_read _rxode2_rc_buf_read
+#define sIniTo _rxode2_sIniTo
+#define sFree _rxode2_sFree
+#define sFreeIni _rxode2_sFreeIni
+#define sAppendN _rxode2_sAppendN
+#define sAppend _rxode2_sAppend
+#define sPrint _rxode2_sPrint
+#define lineIni _rxode2_lineIni
+#define lineFree _rxode2_lineFree
+#define addLine _rxode2_addLine
+#define curLineProp _rxode2_curLineProp
+#define curLineType _rxode2_curLineType
+#define doDot _rxode2_doDot
+#define doDot2 _rxode2_doDot2
+
+#include <rxode2parseSbuf.h>
 
 #include <float.h>
 #include <stdio.h>
@@ -28,10 +46,13 @@
 
 #define max2( a , b )  ( (a) > (b) ? (a) : (b) )
 #define isSameTime(xout, xp) ((xout)-(xp) <= DBL_EPSILON*max2(fabs(xout),fabs(xp)))
+void parseFree(int last);
 
 #else
+
 #if defined(__cplusplus)
 #include "rxode2_RcppExports.h"
+
 #endif
 
 #endif // _isrxode2_
@@ -50,7 +71,7 @@ typedef void (*t_update_inis)(int cSub, double *);
 typedef void (*t_dydt_lsoda_dum)(int *neq, double *t, double *A, double *DADT);
 typedef void (*t_jdum_lsoda)(int *neq, double *t, double *A,int *ml, int *mu, double *JAC, int *nrowpd);
 typedef int (*t_dydt_liblsoda)(double t, double *y, double *ydot, void *data);
-typedef void (*t_ode_current)();
+typedef void (*t_ode_current)(void);
 typedef double (*t_F)(int _cSub,  int _cmt, double _amt, double t, double *y);
 typedef double (*t_LAG)(int _cSub,  int _cmt, double t);
 typedef double (*t_RATE)(int _cSub,  int _cmt, double _amt, double t);
@@ -60,259 +81,14 @@ typedef void (*t_calc_mtime)(int cSub, double *mtime);
   
 typedef void (*t_ME)(int _cSub, double _t, double t, double *_mat, const double *__zzStateVar__);
 typedef void (*t_IndF)(int _cSub, double _t, double t, double *_mat);
-
-typedef struct sbuf {
-  char *s;        /* curr print buffer */
-  int sN;
-  int o;                        /* offset of print buffer */
-} sbuf;
-  
-typedef struct vLines {
-  char *s;
-  int sN;
-  int o;
-  int n;
-  int nL;
-  char **line;
-  int *lProp;
-  int *lType;
-  int *os;
-} vLines;
-
-typedef struct {
-  // These options should not change based on an individual solve
-  int badSolve;
-  int naTime;
-  double ATOL; //absolute error
-  double RTOL; //relative error
-  double H0;
-  double HMIN;
-  int mxstep;
-  int MXORDN;
-  int MXORDS;
-  //
-  int nlhs;
-  int neq;
-  int stiff;
-  int ncov;
-  char modNamePtr[1000];
-  int *par_cov;
-  double *inits;
-  double *scale;
-  bool do_par_cov;
-  // approx fun options
-  double f1;
-  double f2;
-  int kind;
-  int is_locf;
-  int cores;
-  int doesRandom;
-  int extraCmt;
-  double hmax2; // Determined by diff
-  double *rtol2;
-  double *atol2;
-  double *ssRtol;
-  double *ssAtol;
-  int *indLin;
-  int indLinN;
-  double indLinPhiTol;
-  int indLinPhiM;
-  int indLinMatExpType;
-  int indLinMatExpOrder;
-  int nDisplayProgress;
-  int ncoresRV;
-  int isChol;
-  int nsvar;
-  int abort;
-  int minSS;
-  int maxSS;
-  int doIndLin;
-  int strictSS;
-  double infSSstep;
-  int mxhnil;
-  double hmxi;
-  int nlin;
-  int nlin2;
-  int nlinR;
-  int linBflag;
-  bool cTlag;
-  double hTlag;
-  bool cF;
-  double hF;
-  bool cRate;
-  double hRate;
-  bool cDur;
-  double hDur;
-  bool cTlag2;
-  double hTlag2;
-  bool cF2;
-  double hF2;
-  bool cRate2;
-  double hRate2;
-  bool cDur2;
-  double hDur2;
-  int nLlik;
-} rx_solving_options;
-
-
-typedef struct {
-  double bT;
-  int *slvr_counter;
-  int *dadt_counter;
-  int *jac_counter;
-  double *InfusionRate;
-  int *BadDose;
-  int nBadDose;
-  double HMAX; // Determined by diff
-  double tlast;
-  double curDose;
-  int dosenum;
-  double tfirst;
-  double *tlastS;
-  double *curDoseS;
-  double *tfirstS;
-  double podo;
-  double *podoS;
-  double *par_ptr; // both time changing and time invariant
-  double *dose;
-  double *ii;
-  double *solve;
-  double *mtime;
-  double *solveSave;
-  double *solveLast;
-  double *solveLast2;
-  double *lhs;
-  int  *evid;
-  int *rc;
-  double *cov_ptr;
-  int *cov_sample;
-  // a b
-  // 1 4
-  // 2 5
-  // 3 6
-  int n_all_times;
-  int nevid2;
-  int ixds;
-  int ndoses;
-  double *all_times;
-  int *ix;
-  double *dv;
-  double *limit;
-  int *cens;
-  int *idose;
-  int *on;
-  int idosen;
-  int id;
-  int idReal;
-  int sim;
-  int idx;
-  double ylow;
-  double yhigh;
-  double logitHi;
-  double logitLow;
-  double lambda;
-  double yj;
-  // Saved info
-  int wh;
-  int wh100;
-  int cmt;
-  int whI;
-  int wh0;
-  int doSS;
-  int allCovWarn;
-  int wrongSSDur;
-  int _newind;
-  int _rxFlag;
-  int err;
-  int solved;
-  double *linCmtAdvan;
-  double *linCmtRate;
-  int linCmt;
-  int linCmtAdvanSetup;
-  int cacheME;
-  int inLhs;
-  // Cache alag
-  double *alag;
-  // Cache F
-  double *cF;
-  // Cache rate;
-  double *cRate;
-  // Cache duration
-  double *cDur;
-  double solveTime;
-  double curShift;
-  double *simIni;
-  int isIni;
-  int _update_par_ptr_in;
-  int badIni;
-  double *llikSave;
-} rx_solving_options_ind;
-
-typedef struct {
-  rx_solving_options_ind *subjects;
-  rx_solving_options *op;
-  int nsub;
-  int nsim;
-  int neta;
-  int neps;
-  int nIndSim;
-  int simflg;
-  int nall;
-  int nevid9;
-  int nobs;
-  int nobs2;
-  int nr;
-  int add_cov;
-  int matrix;
-  int needSort;
-  int nMtime;
-  double stateTrimU;
-  double stateTrimL;
-  int *stateIgnore;
-  int nCov0;
-  int *cov0;
-  int nKeepF;
-  int istateReset;
-  int cens;
-  int limit;
-  int safeZero;
-  int sumType;
-  int prodType;
-  int sensType;
-  vLines factors;
-  vLines factorNames;
-  int factorNs[500];
-  int hasFactors;
-  // For forder
-  uint64_t minD;
-  uint64_t maxD;
-  int maxAllTimes;
-  uint8_t ***keys;// = NULL; keys per thread
-  int *TMP;
-  int *ordId;
-  uint8_t *UGRP;
-  int *nradix;
-  double *ypNA;
-  bool sample;
-  int *par_sample;
-  double maxShift;
-  int linKa;
-  int linNcmt;
-  int maxwhile;
-  int whileexit;
-  int *svar;
-  int *ovar;
-  int hasEvid2;
-  int useStdPow;
-} rx_solve;
   
 typedef void (*t_set_solve)(rx_solve *);
-typedef rx_solve *(*t_get_solve)();
+typedef rx_solve *(*t_get_solve)(void);
 
-typedef void *(*t_assignFuns)();
+typedef void *(*t_assignFuns)(void);
 
-rx_solve *getRxSolve_();
-rx_solve *getRxSolve2_();
+rx_solve *getRxSolve_(void);
+rx_solve *getRxSolve2_(void);
 rx_solve *getRxSolve(SEXP ptr);
 
 void par_solve(rx_solve *rx);
@@ -320,7 +96,7 @@ void par_solve(rx_solve *rx);
 rx_solving_options *getRxOp(rx_solve *rx);
 
 SEXP rxode2_df(int doDose, int doTBS);
-SEXP rxode2_par_df();
+SEXP rxode2_par_df(void);
 
 void rxOptionsIniEnsure(int mx);
 
@@ -358,6 +134,7 @@ static inline void _splitYj(int *yj, int *dist,  int *trans) {
 // Inverse 
 static inline double _powerDi(double x, double lambda, int yj0, double low, double high)  __attribute__((unused));
 static inline double _powerDi(double x, double lambda, int yj0, double low, double high){
+  if (!R_finite(x)) return NA_REAL;
   double x0=x, ret, l2, yjd;
   int yj, dist;
   _splitYj(&yj0, &dist,  &yj);
@@ -432,6 +209,7 @@ static inline double _powerDi(double x, double lambda, int yj0, double low, doub
 
 static inline double _powerD(double x, double lambda, int yj0, double low, double high)  __attribute__((unused));
 static inline double _powerD(double x, double lambda, int yj0, double low, double high) {
+  if (!R_finite(x)) return NA_REAL;
   double x0=x, l2, p;
   int yj, dist;
   _splitYj(&yj0, &dist,  &yj);
@@ -503,6 +281,7 @@ static inline double _powerD(double x, double lambda, int yj0, double low, doubl
 
 static inline double _powerDD(double x, double lambda, int yj0, double low, double high)  __attribute__((unused));
 static inline double _powerDD(double x, double lambda, int yj0, double low, double high){
+  if (!R_finite(x)) return NA_REAL;
   double x0 = x, xl, hl,eri;
   int yj, dist;
   _splitYj(&yj0, &dist,  &yj);
@@ -548,6 +327,7 @@ static inline double _powerDD(double x, double lambda, int yj0, double low, doub
 
 static inline double _powerDDD(double x, double lambda, int yj0, double low, double high) __attribute__((unused));
 static inline double _powerDDD(double x, double lambda, int yj0, double low, double high){
+  if (!R_finite(x)) return NA_REAL;
   double x0 = x, hl, hl2, xl,  t1, dL, eri;
   int yj, dist;
   _splitYj(&yj0, &dist,  &yj);
@@ -597,6 +377,7 @@ static inline double _powerDDD(double x, double lambda, int yj0, double low, dou
 
 static inline double _powerL(double x, double lambda, int yj0, double low, double high) __attribute__((unused));
 static inline double _powerL(double x, double lambda, int yj0, double low, double high){
+  if (!R_finite(x)) return NA_REAL;
   double x0 = x, hl, xl, hl2, eri;
   int yj, dist;
   _splitYj(&yj0, &dist,  &yj);
@@ -653,6 +434,7 @@ static inline double _powerL(double x, double lambda, int yj0, double low, doubl
 static inline double _powerDL(double x, double lambda, int yj0, double low, double hi) __attribute__((unused));
 static inline double _powerDL(double x, double lambda, int yj0, double low, double hi) {
   // d(logLik/dlambda)
+  if (!R_finite(x)) return NA_REAL;
   double x0 = x;
   int yj, dist;
   _splitYj(&yj0, &dist,  &yj);
@@ -713,25 +495,6 @@ static inline double dabs2(double x) {
   return 0.0;
 }
 
-static inline void sNull(sbuf *sbb) {
-  sbb->s = NULL;
-  sbb->sN=0;
-  sbb->o=0;
-}
-
-static inline void lineNull(vLines *sbb) {
-  sbb->s = NULL;
-  sbb->lProp = NULL;
-  sbb->lType = NULL;
-  sbb->line = NULL;
-  sbb->os = NULL;
-  sbb->sN = 0;
-  sbb->nL = 0;
-  sbb->n  = 0;
-  sbb->o  = 0;
-}
-
-
 extern rx_solve rx_global;
 extern rx_solving_options op_global;
 extern rx_solving_options_ind *inds_global;
