@@ -1,5 +1,4 @@
 rxTest({
-  
   .rx <- loadNamespace("rxode2")
 
   testPipeQuote <- function(..., envir=parent.frame()) {
@@ -1621,3 +1620,24 @@ rxTest({
 
   })
 })
+
+test_that("eff(0) piping should work", {
+  mod1 <- rxode2({
+    C2 <- centr/V2
+    C3 <- peri/V3
+    d/dt(depot) <- -KA*depot
+    d/dt(centr) <- KA*depot - CL*C2 - Q*C2 + Q*C3
+    d/dt(peri)  <- Q*C2 - Q*C3
+    d/dt(eff)   <- Kin - Kout*(1-C2/(EC50+C2))*eff
+  })
+
+  expect_error(mod1 %>%
+                 model(KA<-exp(tka+eta.ka), append=NA) %>% # Prepend a line by append=NA
+                 ini(tka=log(2.94E-01),
+                     eta.ka=0.2,
+                     CL=1.86E+01, V2=4.02E+01, # central
+                     Q=1.05E+01,  V3=2.97E+02, # peripheral
+                     Kin=1, Kout=1, EC50=200) %>%
+                 model(eff(0) <- 1), NA)
+
+})
